@@ -2,7 +2,7 @@ from functools import wraps
 from typing import Callable
 
 from django.http import HttpRequest, HttpResponse, HttpResponseForbidden, HttpResponseNotFound
-from nidhoggr.core.response import StatusResponse
+from nidhoggr.core.response import ErrorResponse
 from pydantic import ValidationError
 from pydantic.main import BaseModel
 
@@ -16,8 +16,8 @@ def typed(func: Callable[[BaseModel], BaseModel]) -> Callable[[HttpRequest], Bas
             # noinspection PyUnresolvedReferences
             tpe: BaseModel = func.__annotations__['req']  # by convention
             req: BaseModel = tpe.parse_raw(request.body)
-        except ValidationError:
-            return StatusResponse(status=False, reason="Failed to decode payload")
+        except ValidationError as e:
+            return ErrorResponse(reason=f"Failed to decode payload {request.body}", exception=str(e))
         else:
             return func(req)
 
